@@ -11,6 +11,11 @@ test_that("pick_phylopic works", {
   expect_true(is(pick_phylopic(name = "Bacteria", n = 13,
                                view = 5, auto = 2),
                  "Picture"))
+  
+  # Test attribution information
+  expect_equal(
+    length(pick_phylopic(name = "Scleractinia", n = 4, view = 4, auto = 3)),
+           4)
 
   # Expect warning
   expect_warning(pick_phylopic(name = "Acropora cervicornis", n = 10))
